aboutsummaryrefslogtreecommitdiff
path: root/source/binarytree.py
diff options
context:
space:
mode:
Diffstat (limited to 'source/binarytree.py')
-rw-r--r--source/binarytree.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/binarytree.py b/source/binarytree.py
index 036e89ba..8a793540 100644
--- a/source/binarytree.py
+++ b/source/binarytree.py
@@ -5,7 +5,7 @@
class CNode(object):
"""
- Represent a node.
+ Represents a node.
"""
def __init__(self, data):
"""
@@ -17,7 +17,7 @@ class CNode(object):
class CBOrdTree(object):
"""
Represent a binary ordered tree.
"""
def __init__(self):
"""
@@ -17,7 +17,7 @@ class CNode(object):
class CBOrdTree(object):
"""
- Represent a binary ordered tree.
+ Represents a binary ordered tree.
"""
def __init__(self):
bgstack15